using namespace std; 

void plot4user(string user_name)
{
  //------------------Extracting parameters from analysis output file-------------------

  vector<double> meanNumOfDoublets_SC;
  vector<double> counterNumOfDoublets_Data;
  vector<double> sigma_doublet;
  vector<double> threeSig_doublet;
  vector<double> fiveSig_doublet;
  vector<double> days;
  vector<double> excess;

  int numOfPoints = 0;
  double a,b,c,d,e,f;
  double j = 0;

  ifstream input;
  char data_in [256];
  sprintf(data_in,"output_parameters_%s.txt",user_name.c_str());
  string line;

  input.open(data_in);
  if (!input)
 	{
   	cout << "Unable to open file." << endl;
   	return 0;
 	}

  while (input >> a >> b >> c >> d >> e >> f)
 	{
    j++;
    days.push_back(j);
  
   	meanNumOfDoublets_SC.push_back(a);
    counterNumOfDoublets_Data.push_back(b);
    sigma_doublet.push_back(c);
    threeSig_doublet.push_back(d);
    fiveSig_doublet.push_back(e);
    excess.push_back(f);

    numOfPoints++;   		     	   	
  }
  input.close();
  
  //-------------------------------------------------------------------------------

  //------------------------------------PLOT---------------------------------------
	TString plot_name = TString::Format("plot_user-%s.root",user_name.c_str());
	TFile file1(plot_name, "RECREATE");

  TString canvas_name = TString::Format("Live plot of smartphone data for user %s",user_name.c_str());
	TCanvas *c1 = new TCanvas("c1",canvas_name);
	c1->Divide(1,2);

  c1->cd(1);
  c1_1->SetGridx();
  c1_1->SetGridy();

  TGraph* gr1 = new TGraph(numOfPoints,&days[0],&meanNumOfDoublets_SC[0]);
  gr1->SetMarkerStyle(3);
  gr1->SetMarkerColor(kBlue+3);
  gr1->SetLineStyle(1);
  gr1->SetLineColor(kBlue+3);

  TGraph* gr2 = new TGraph(numOfPoints,&days[0],&counterNumOfDoublets_Data[0]);
  gr2->SetMarkerStyle(3);
  gr2->SetMarkerColor(2);
  gr2->SetLineStyle(1);
  gr2->SetLineColor(2);

  TGraph* gr3 = new TGraph(numOfPoints,&days[0],&threeSig_doublet[0]);
  gr3->SetMarkerStyle(8);
  gr3->SetMarkerColor(kGreen+2);
  gr3->SetLineStyle(10);
  gr3->SetLineColor(kGreen+2);
  gr3->SetFillStyle(3002);
  gr3->SetFillColor(kGreen+2);

  TGraph* gr4 = new TGraph(numOfPoints,&days[0],&fiveSig_doublet[0]);
  gr4->SetMarkerStyle(8);
  gr4->SetMarkerColor(7);
  gr4->SetLineStyle(10);
  gr4->SetLineColor(7);

  TMultiGraph *mg = new TMultiGraph();

  mg->Add(gr1);
  mg->Add(gr2);
  mg->Add(gr3);
  mg->Add(gr4);
  TString mg_title = TString::Format("# of doublets in 5 min. time windows - User %s",user_name.c_str());
  mg->SetTitle(mg_title);  
  mg->Draw("ACP");
  mg->GetXaxis()->SetTitle("Days");
  mg->GetXaxis()->SetLabelSize(0.04);
  mg->GetXaxis()->SetTitleSize(0.06);
  mg->GetXaxis()->SetTitleOffset(0.75);
  mg->GetXaxis()->SetRangeUser(0,76);
  mg->GetYaxis()->SetTitle("Number of doublets");
  mg->GetYaxis()->SetLabelSize(0.04);
  mg->GetYaxis()->SetTitleSize(0.05);
  mg->GetYaxis()->SetTitleOffset(1);
  mg->GetYaxis()->SetTickLength(0.01);

  auto Legend1 = new TLegend(0.1,0.9,0.3,0.8);
  Legend1->AddEntry(gr1,"Expected value","l");
  Legend1->AddEntry(gr2,"Observed value","l");
  Legend1->Draw();

  auto Legend2 = new TLegend(0.3,0.9,0.45,0.8);
  Legend2->AddEntry(gr3,"3-sigma limit","l");
  Legend2->AddEntry(gr4,"5-sigma limit","l");
  Legend2->Draw();

  gPad->Modified();

  c1->cd(2);
  c1_2->SetGridx();
  c1_2->SetGridy();

  TGraph* gr5 = new TGraph(numOfPoints,&days[0],&sigma_doublet[0]);
  gr5->SetMarkerStyle(3);
  gr5->SetMarkerColor(kBlue+3);
  gr5->SetLineStyle(1);
  gr5->SetLineColor(kBlue+3);
  gr5->SetTitle("Significance of # of doublets in data");
  gr5->GetXaxis()->SetTitle("Days");
  gr5->GetXaxis()->SetLabelSize(0.04);
  gr5->GetXaxis()->SetTitleSize(0.06);
  gr5->GetXaxis()->SetTitleOffset(0.75);
  gr5->GetYaxis()->SetTitle("# of standard deviations - sigma");
  gr5->GetYaxis()->SetLabelSize(0.04);
  gr5->GetYaxis()->SetTitleSize(0.05);
  gr5->GetYaxis()->SetTitleOffset(1);
  gr5->GetYaxis()->SetTickLength(0.01);
  int nbins=mg->GetXaxis()->GetNbins();
  double xlo = mg->GetXaxis()->GetBinLowEdge(mg->GetXaxis()->GetFirst());
  double xhi = mg->GetXaxis()->GetBinUpEdge(mg->GetXaxis()->GetLast());
  gr5->GetXaxis()->Set(nbins, xlo, xhi);
  gr5->Draw("ALP");

  gPad->Modified();

	c1->Write();

  TString plot_name_png = TString::Format("plot_user-%s.png",user_name.c_str());
  c1->Print(plot_name_png);
}
